@@ -14,11 +14,11 @@
 #'
 #' ## Power for alpha = 0.05, N = 53 per group, equivalence bounds of
 #' ## -200 and 200 in raw units, assuming sdpooled = 350 and true effect = 0
-#' powerTOSTtwo.raw(alpha=0.05,N = 53,low_eqbound=-200,high_eqbound=200,sdpooled=350)
+#' powerTOSTtwo.raw(alpha=0.05, N=53, low_eqbound=-200, high_eqbound=200, sdpooled=350)
 #'
 #' ## Equivalence bounds for alpha = 0.05, N = 108 per group, statistical power of
 #' ## 0.8, assuming true effect = 0
-#' powerTOSTtwo.raw(alpha=0.05, N=108, statistical_power=0.8)
+#' powerTOSTtwo.raw(alpha=0.05, N=53, statistical_power=0.8, sdpooled=350)
 
 #' @section References:
 #' Chow, S.-C., Wang, H., & Shao, J. (2007). Sample Size Calculations in Clinical Research, Second Edition - CRC Press Book. Formula 3.2.4 with k = 1
@@ -30,8 +30,8 @@ powerTOSTtwo.raw<-function(alpha, statistical_power, N, sdpooled, low_eqbound, h
   if(missing(N)) {
     NT1<-2*sdpooled^2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/(low_eqbound)^2
     NT2<-2*sdpooled^2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/(high_eqbound)^2
-    N<-ceiling(max(NT1,NT2))
-    message(cat("The required sample size to achieve",100*statistical_power,"% power with equivalence bounds of",low_eqbound,"and",high_eqbound,"is",N,"per group, or", 2*N,"in total."))
+    N<-max(NT1,NT2)
+    message(cat("The required sample size to achieve",100*statistical_power,"% power with equivalence bounds of",low_eqbound,"and",high_eqbound,"is",N,"per group, or", 2*ceiling(N),"in total."))
     return(N)
   }
   if(missing(statistical_power)) {
@@ -43,8 +43,8 @@ powerTOSTtwo.raw<-function(alpha, statistical_power, N, sdpooled, low_eqbound, h
     return(statistical_power)
   }
   if(missing(low_eqbound) && missing(high_eqbound)) {
-    low_eqbound<--sqrt(2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/N)
-    high_eqbound<-sqrt(2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/N)
+    low_eqbound<--sqrt(2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/N)*sdpooled
+    high_eqbound<-sqrt(2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/N)*sdpooled
     message(cat("The equivalence bounds to achieve",100*statistical_power,"% power with N =",N,"are",round(low_eqbound,2),"and",round(high_eqbound,2),"."))
     bounds<-c(low_eqbound,high_eqbound)
     return(bounds)
